@@ -9,7 +9,8 @@
 # did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
-package Kernel::System::Email;
+package
+    Kernel::System::Email;
 
 use strict;
 use warnings;
